==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/General/lyrics/translations/lyrics_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>הצג מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>אודות תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>תוספת מילות שיר Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>תוספת מאחזרת מילות שיר מן LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>אמן:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>כותרת:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>אין חיבור</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>סיום</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>לא נמצאו</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translatorcomment>מקבל כעת</translatorcomment>
        <translation>קבלה</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>מילות שיר: %1 - %2</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/lyrics/translations/lyrics_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>הצג מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>אודות תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>תוספת מילות שיר של Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>תוספת מאחזרת מילות שיר מתוך LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>תוספת מילות שיר</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>אמן:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>כותרת:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>אין חיבור</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>סיום</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>לא נמצאו</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translatorcomment>מקבל כעת</translatorcomment>
        <translation>קבלה</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>מילות שיר: %1 - %2</translation>
    </message>
</context>
</TS>
